powered by
A convenience function using either character vectors or numeric vectors to specify a subset of names of a data.frame.
names
data.frame
Names(data, invec)
A character vector of the desired names.
The input data.frame.
The names you want.
Ananda Mahto
mydf <- data.frame(a = 1:2, b = 3:4, c = 5:6) splitstackshape:::Names(mydf, c("a", "c")) splitstackshape:::Names(mydf, c(1, 3))
Run the code above in your browser using DataLab