Learn R Programming

splitstackshape (version 1.4.8.1)

getanID: Add an "id" Variable to a Dataset

Description

Many functions will not work properly if there are duplicated ID variables in a dataset. This function is a convenience function for .N from the "data.table" package to create an .id variable that when used in conjunction with the existing ID variables, should be unique.

Usage

getanID(data, id.vars = NULL)

Value

The input dataset (as a data.table) if ID variables are unique, or the input dataset with a new column named .id.

Arguments

data

The input data.frame or data.table.

id.vars

The variables that should be treated as ID variables. Defaults to NULL, at which point all variables are used to create the new ID variable.

Author

Ananda Mahto

Examples

Run this code

mydf <- data.frame(IDA = c("a", "a", "a", "b", "b"),
                   IDB = c(1, 1, 1, 1, 1), values = 1:5)
mydf
getanID(mydf, c("IDA", "IDB"))

mydf <- data.frame(IDA = c("a", "a", "a", "b", "b"),
                   IDB = c(1, 2, 1, 1, 2), values = 1:5)
mydf
getanID(mydf, 1:2)

rm(mydf)

Run the code above in your browser using DataLab