| listCol_l | R Documentation |
Unlists a column stored as a list into a long form.
listCol_l(inDT, listcol, drop = TRUE)
inDT |
The input dataset. |
listcol |
The name of the column stored as a |
drop |
Logical. Should the original column be dropped? Defaults to |
A data.table.
Ananda Mahto
listCol_w to flatten a list column into a "wide" format.
dat <- data.frame(A = 1:3, B = I(list(c(1, 2), c(1, 3, 5), c(4))))
listCol_l(dat, "B")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.