Learn R Programming

splitstackshape (version 1.4.8.1)

charMat: Create a Binary Matrix from a List of Character Values

Description

Create a binary matrix from a list of character values

Usage

charMat(listOfValues, fill = NA, mode = "binary")

Value

A matrix.

Arguments

listOfValues

A list of input values to be inserted in a matrix.

fill

The initializing fill value for the empty matrix.

mode

Either "binary" or "value". Defaults to "binary".

Author

Ananda Mahto

Details

This is primarily a helper function for the concat.split() function when creating the "expanded" structure. The input is anticipated to be a list of values obtained using base::strsplit().

See Also

base::strsplit(), numMat().

Examples

Run this code

invec <- c("rock,electro","electro","rock,jazz")
A <- strsplit(invec, ",")
splitstackshape:::charMat(A)
splitstackshape:::charMat(A, 0)
splitstackshape:::charMat(A, mode = "value")

Run the code above in your browser using DataLab