powered by
Unlists a column stored as a list into a long form.
list
listCol_l(inDT, listcol, drop = TRUE)
A data.table.
data.table
The input dataset.
The name of the column stored as a list.
Logical. Should the original column be dropped? Defaults to TRUE.
TRUE
Ananda Mahto
listCol_w to flatten a list column into a "wide" format.
listCol_w
dat <- data.frame(A = 1:3, B = I(list(c(1, 2), c(1, 3, 5), c(4)))) listCol_l(dat, "B")
Run the code above in your browser using DataLab